@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Meta;
 BEGIN {
-  $Dist::Zilla::Plugin::GitHub::Meta::VERSION = '0.06';
+  $Dist::Zilla::Plugin::GitHub::Meta::VERSION = '0.07';
 }
 
 use Moose;
@@ -38,7 +38,7 @@ Dist::Zilla::Plugin::GitHub::Meta - Add GitHub repo info to META.{yml,json}
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -198,4 +198,8 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
+no Moose;
+
+__PACKAGE__ -> meta -> make_immutable;
+
 1; # End of Dist::Zilla::Plugin::GitHub::Meta
\ No newline at end of file
